==> 0.1.0a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/ChineseData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources._10_strawberries
import kotlin.time.Duration

val chineseList = listOf(
    Recipe(
        title = "Sweet & Sour Noodle Bowl",
        description = "Chinese Stir Fried Noodle Bowl with a Spicy Sweet & Sour Sauce.",
        prepTime = Duration.parse("10m"),
        cookTime = Duration.parse("15m"),
        servings = "3 Noodle Bowls",
        ingredients = listOf(
            "1 lb Wheat Noodles, cooked and drained",
            "3/4 Cup Rice Wine Vinegar",
            "1/2 Cup Honey",
            "1/3 Cup Soy Sauce",
            "4 Tbsp Sesame Oil, divided",
            "2 Tbsp Lime Juice",
            "1 Tbsp Chili-Garlic Sauce",
            "1 to 2 Tsp Ground Ginger, to taste",
            "1 large Red Bell Pepper, trimmed, seeded, and sliced into thin strips",
            "1/3 Cup Scallions (about 4), trimmed and sliced into thin rounds, plus more for garnishing",
            "1/4 Cup fresh Cilantro Leaves, finely minced",
            "1 Tbsp Sesame Seeds, toasted if desired, optional for garnishing",
        ),
        instructions = listOf(
            "Cook Wheat Noodles. Drain and set aside.",
            "Add Rice Wine Vinegar [3/4 Cup], Honey [1/2 Cup], Soy [1/3 Cup], Sesame Oil [2 Tbsp], Lime Juice [2 Tbsp], Chili Garlic Sauce [1 Tbsp], and Ginger [1.5 Tsp] to a bowl and whisk to combine. Set Aside.",
            "In a skillet, add Sesame Oil [2 Tbsp], Peppers, and cook until peppers are soft, about 5 minutes.",
            "Add the cooked Noodles, Sauce, and cook for about 2 minutes or warmed through. Toss Often until most of the sauce is absorbed.",
            "Garnish with Cilantro, Sesame Seeds, Scallions. Serve",
        ),
        tags = mapOf(
            "Chinese" to TagType.CUISINE,
            "Entree" to TagType.COURSE,
            "Stir Fried" to TagType.TECHNIQUE,
            "Spicy" to TagType.FLAVOUR,
            "Sweet" to TagType.FLAVOUR,
            "Sour" to TagType.FLAVOUR,
        ),
        image = Res.drawable._10_strawberries
    )
)

==> 0.1.2a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/model/ChineseData.kt <==
package model

import recipeappkmp.shared.generated.resources.Res
import recipeappkmp.shared.generated.resources._10_strawberries
import kotlin.time.Duration

val chineseList = listOf(
    Recipe(
        title = "Sweet & Sour Noodle Bowl",
        description = "Chinese Stir Fried Noodle Bowl with a Spicy Sweet & Sour Sauce.",
        prepTime = Duration.parse("10m"),
        cookTime = Duration.parse("15m"),
        servings = "3 Noodle Bowls",
        ingredients = listOf(
            "1 lb Wheat Noodles, cooked and drained",
            "3/4 Cup Rice Wine Vinegar",
            "1/2 Cup Honey",
            "1/3 Cup Soy Sauce",
            "4 Tbsp Sesame Oil, divided",
            "2 Tbsp Lime Juice",
            "1 Tbsp Chili-Garlic Sauce",
            "1 to 2 Tsp Ground Ginger, to taste",
            "1 large Red Bell Pepper, trimmed, seeded, and sliced into thin strips",
            "1/3 Cup Scallions (about 4), trimmed and sliced into thin rounds, plus more for garnishing",
            "1/4 Cup fresh Cilantro Leaves, finely minced",
            "1 Tbsp Sesame Seeds, toasted if desired, optional for garnishing",
        ),
        instructions = listOf(
            "Cook Wheat Noodles. Drain and set aside.",
            "Add Rice Wine Vinegar [3/4 Cup], Honey [1/2 Cup], Soy [1/3 Cup], Sesame Oil [2 Tbsp], Lime Juice [2 Tbsp], Chili Garlic Sauce [1 Tbsp]," +
                    " and Ginger [1.5 Tsp] to a bowl and whisk to combine. Set Aside.",
            "In a skillet, add Sesame Oil [2 Tbsp], Peppers, and cook until peppers are soft, about 5 minutes.",
            "Add the cooked Noodles, Sauce, and cook for about 2 minutes or warmed through. Toss Often until most of the sauce is absorbed.",
            "Garnish with Cilantro, Sesame Seeds, Scallions. Serve",
        ),
        tags = mapOf(
            "Chinese" to TagType.CUISINE,
            "Entree" to TagType.COURSE,
            "Stir Fried" to TagType.TECHNIQUE,
            "Spicy" to TagType.FLAVOUR,
            "Sweet" to TagType.FLAVOUR,
            "Sour" to TagType.FLAVOUR,
        ),
        image = Res.drawable._10_strawberries
    ),
)
